{-# LANGUAGE OverloadedStrings #-}
-- | Build time configuration used during code generation.
module GI.GtkLayerShell.Config ( overrides, modules ) where

import qualified Data.Text as T
import Data.Text (Text)

-- | Overrides used when generating these bindings.
overrides :: Text
overrides = T.unlines
 [ "# Generated by xsltproc Nullable.xslt /usr/share/gir-1.0/GtkLayerShell-0.1.gir"
 , "set-attr GtkLayerShell/get_zwlr_layer_surface_v1/@return-value nullable 1"]

-- | Modules in this package
modules :: [Text]
modules =  [ "GI.GtkLayerShell.Config"
 , "GI.GtkLayerShell"
 , "GI.GtkLayerShell.Enums"
 , "GI.GtkLayerShell.Functions"]
